@@ -30,6 +30,8 @@ public:
     Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave = Cantor::Expression::FinishingBehavior::DoNotDelete, bool internal = false) override;
     Cantor::CompletionObject* completionFor(const QString& cmd, int index = -1) override;
     QSyntaxHighlighter* syntaxHighlighter(QObject* parent) override;
+
+    bool isLuaJIT() const;
     lua_State* getState() const;
 
 public Q_SLOTS:
@@ -42,9 +44,19 @@ private Q_SLOTS:
     void expressionFinished(Cantor::Expression::Status);
 
 private:
+    void readOutputLua();
+    void readOutputLuaJIT();
+    bool isPromptString(const QString&);
+
     lua_State* m_L{nullptr};
     QProcess* m_process{nullptr};
     LuaExpression* m_lastExpression{nullptr};
+    QStringList m_inputCommands;
+    QStringList m_output;
+    bool m_luaJIT{true};
+
+    static const QString LUA_PROMPT;
+    static const QString LUA_SUBPROMPT;
 };
 
 #endif /* _LUASESSION_H */
