@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2010 Miha Čančula <miha.cancula@gmail.com>
+    SPDX-FileCopyrightText: 2010 Miha Čančula <miha.cancula@gmail.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "octaveextensions.h"
@@ -92,10 +79,8 @@ QString OctaveLinearAlgebraExtension::createMatrix(const Cantor::LinearAlgebraEx
 {
     QString command;
     command += QLatin1Char('[');
-    foreach (const QStringList row, matrix)
-    {
-        foreach (const QString entry, row)
-        {
+    for (const QStringList &row : matrix) {
+        for (const QString &entry : row) {
             command += entry;
             command += QLatin1String(", ");
         }
@@ -120,8 +105,7 @@ QString OctaveLinearAlgebraExtension::createVector(const QStringList& entries, C
     }
     QString command;
     command += QLatin1Char('[');
-    foreach (const QString& entry, entries)
-    {
+    for (const QString& entry : entries) {
         command += entry;
         command += separator;
     }
