@@ -62,7 +62,6 @@ void QalculateExpression::evaluate()
         return;
     }
 
-
     const auto& commands = command().split(QLatin1Char('\n'));
     for(const auto& command : commands)
     {
@@ -842,7 +841,7 @@ QSharedPointer<PrintOptions> QalculateExpression::printOptions()
 
     po->lower_case_e = true;
     po->base = QalculateSettings::base();
-    po->decimalpoint_sign = QLocale().decimalPoint().toLatin1();
+    po->decimalpoint_sign = QLocale().decimalPoint().toLatin1().toStdString();
 
     switch (QalculateSettings::minExp()) {
     case 0:
