@@ -1,6 +1,7 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
     SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+    SPDX-FileCopyrightText: 2023 Alexander Semke <alexander.semke@web.de>
 */
 
 #include "testsage.h"
@@ -27,11 +28,11 @@ void TestSage::initTestCase() {
 
 void TestSage::testSimpleCommand()
 {
-    Cantor::Expression* e=evalExp( QLatin1String("2+2") );
+    auto* e = evalExp( QLatin1String("2+2") );
 
-    QVERIFY( e!=nullptr );
-    QVERIFY( e->result()!=nullptr );
-    QCOMPARE( e->result()->data().toString(), QLatin1String(("4")) );
+    QVERIFY(e != nullptr);
+    QVERIFY(e->result() != nullptr);
+    QCOMPARE(e->result()->data().toString(), QLatin1String(("4")));
 }
 
 void TestSage::testCommandQueue()
@@ -39,9 +40,9 @@ void TestSage::testCommandQueue()
     //only wait for the last Expression to return, so the queue gets
     //actually filled
 
-    Cantor::Expression* e1=session()->evaluateExpression(QLatin1String("0+1"));
-    Cantor::Expression* e2=session()->evaluateExpression(QLatin1String("1+1"));
-    Cantor::Expression* e3=evalExp(QLatin1String("1+2"));
+    auto* e1 = evalExp(QLatin1String("0+1"));
+    auto* e2 = evalExp(QLatin1String("1+1"));
+    auto* e3 = evalExp(QLatin1String("1+2"));
 
     QVERIFY(e1!=nullptr);
     QVERIFY(e2!=nullptr);
@@ -58,11 +59,11 @@ void TestSage::testCommandQueue()
 
 void TestSage::testMultilineCommand()
 {
-    Cantor::Expression* e=evalExp( QLatin1String("2+2 \n simplify(1 - x + x)") );
+    auto* e = evalExp( QLatin1String("2+2 \n simplify(1 - x + x)") );
 
-    QVERIFY( e!=nullptr );
-    QVERIFY( e->result()!=nullptr );
-    QCOMPARE( e->result()->data().toString(), QLatin1String("4\n1") );
+    QVERIFY(e != nullptr);
+    QVERIFY(e->result() != nullptr);
+    QCOMPARE(e->result()->data().toString(), QLatin1String("4\n1") );
 }
 
 void TestSage::testDefineFunction()
@@ -70,44 +71,45 @@ void TestSage::testDefineFunction()
     const char* cmd="def func1(param) : \n" \
                     "    return param*param\n\n";
 
-    Cantor::Expression* e1=evalExp( QLatin1String(cmd) );
+    auto* e1 = evalExp(QLatin1String(cmd));
+    QVERIFY(e1 != nullptr);
 
-    QVERIFY( e1!=nullptr );
-
-    Cantor::Expression* e2=evalExp( QLatin1String("func1(2)") );
-    QVERIFY( e2!=nullptr );
-    QVERIFY( e2->result()!=nullptr );
-    QCOMPARE( e2->result()->data().toString(), QLatin1String("4") );
+    auto* e2 = evalExp( QLatin1String("func1(2)"));
+    QVERIFY(e2 != nullptr);
+    QVERIFY(e2->result() != nullptr );
+    QCOMPARE(e2->result()->data().toString(), QLatin1String("4"));
 }
 
 void TestSage::testPlot()
 {
-    Cantor::Expression* e=evalExp( QLatin1String("plot(sin(x))") );
+    auto* e = evalExp( QLatin1String("plot(sin(x))") );
 
-    QVERIFY( e!=nullptr );
-    QCOMPARE( e->results().size(), 2);
-    QVERIFY( e->results()[0]->type() == Cantor::TextResult::Type);
-    QCOMPARE( e->results()[0]->data().toString(), QLatin1String("Launched png viewer for Graphics object consisting of 1 graphics primitive"));
+    QVERIFY(e != nullptr);
+    QCOMPARE(e->results().size(), 1);
 
-    QVERIFY( e->results()[1]->type() == Cantor::ImageResult::Type);
-    QVERIFY( !e->results()[1]->data().isNull() );
+    QVERIFY(e->results().at(0)->type() == Cantor::ImageResult::Type);
+    QVERIFY(!e->results().at(0)->data().isNull());
 }
 
 void TestSage::testInvalidSyntax()
 {
-    Cantor::Expression* e=evalExp( QLatin1String("2+2*(") );
+    auto* e = evalExp( QLatin1String("2+2*(") );
 
-    QVERIFY( e!=nullptr );
-    QVERIFY( e->errorMessage()== QLatin1String("Syntax Error") );
+    QVERIFY(e != nullptr);
+    QVERIFY(e->errorMessage()== QLatin1String("Syntax Error"));
 }
 
 void TestSage::testNoOutput()
 {
-    Cantor::Expression* e=evalExp(  QLatin1String("f(x)=x^2+3*x+2\nf(0)") );
+    auto* e = evalExp(  QLatin1String("f(x)=x^2+3*x+2\nf(0)"));
 
-    QVERIFY( e!=nullptr );
-    QVERIFY( e->result() != nullptr );
-    QCOMPARE( e->result()->data().toString(), QLatin1String("2") );
+    QVERIFY(e != nullptr);
+
+   if(session()->status()==Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
+
+    QVERIFY(e->result() != nullptr);
+    QCOMPARE(e->result()->data().toString(), QLatin1String("2"));
 }
 
 void TestSage::testLoginLogout()
@@ -123,20 +125,17 @@ void TestSage::testLoginLogout()
 
 void TestSage::testRestartWhileRunning()
 {
-    Cantor::Expression* e1=session()->evaluateExpression(QLatin1String("import time; time.sleep(5)"));
+    auto* e1 = evalExp(QLatin1String("import time; time.sleep(5)"));
 
     session()->logout();
     QCOMPARE(e1->status(), Cantor::Expression::Interrupted);
     session()->login();
 
-    Cantor::Expression* e2=evalExp( QLatin1String("2+2") );
+    auto* e2 = evalExp(QLatin1String("2+2"));
 
     QVERIFY(e2 != nullptr);
     QVERIFY(e2->result() != nullptr);
-
     QCOMPARE(e2->result()->data().toString(), QLatin1String("4"));
 }
 
-
 QTEST_MAIN( TestSage )
-
